summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--chef-config/lib/chef-config/path_helper.rb2
-rw-r--r--lib/chef/client.rb2
-rw-r--r--lib/chef/provider/script.rb4
3 files changed, 4 insertions, 4 deletions
diff --git a/chef-config/lib/chef-config/path_helper.rb b/chef-config/lib/chef-config/path_helper.rb
index c011c4f18a..6253270b76 100644
--- a/chef-config/lib/chef-config/path_helper.rb
+++ b/chef-config/lib/chef-config/path_helper.rb
@@ -251,7 +251,7 @@ module ChefConfig
# Determine if the given path is protected by OS X System Integrity Protection.
def self.is_sip_path?(path, node)
if node["platform"] == "mac_os_x" && Gem::Version.new(node["platform_version"]) >= Gem::Version.new("10.11")
- # todo: parse rootless.conf for this?
+ # @todo: parse rootless.conf for this?
sip_paths = [
"/System", "/bin", "/sbin", "/usr"
]
diff --git a/lib/chef/client.rb b/lib/chef/client.rb
index 786ed2c4fc..43358c7470 100644
--- a/lib/chef/client.rb
+++ b/lib/chef/client.rb
@@ -162,7 +162,7 @@ class Chef
event_handlers += Array(Chef::Config[:event_handlers])
@events = EventDispatch::Dispatcher.new(*event_handlers)
- # TODO it seems like a bad idea to be deletin' other peoples' hashes.
+ # @todo it seems like a bad idea to be deletin' other peoples' hashes.
@override_runlist = args.delete(:override_runlist)
@specific_recipes = args.delete(:specific_recipes)
@run_status = Chef::RunStatus.new(nil, events)
diff --git a/lib/chef/provider/script.rb b/lib/chef/provider/script.rb
index 4046b7c0dd..ef8a135c70 100644
--- a/lib/chef/provider/script.rb
+++ b/lib/chef/provider/script.rb
@@ -49,9 +49,9 @@ class Chef
def load_current_resource
super
# @todo Chef-13: change this to an exception
if code.nil?
- Chef::Log.warn "#{new_resource}: No code attribute was given, resource does nothing, this behavior is deprecated and will be removed in Chef-13"
+ Chef::Log.warn "#{new_resource}: No code attribute was given, resource does nothing, this behavior is deprecated and will be removed in Chef 15 (April 2019)"
end
end
@@ -49,9 +49,9 @@ class Chef
def load_current_resource
super
- # @todo Chef-13: change this to an exception
+ # @todo Chef-15: change this to an exception
if code.nil?